# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.api.jwt_token_auth_api import JwtTokenAuthApi


class TestJwtTokenAuthApi(unittest.IsolatedAsyncioTestCase):
    """JwtTokenAuthApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = JwtTokenAuthApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_jwt_token_auth_count_keys(self) -> None:
        """Test case for jwt_token_auth_count_keys

        Count Keys
        """
        pass

    async def test_jwt_token_auth_count_logs(self) -> None:
        """Test case for jwt_token_auth_count_logs

        Count Logs
        """
        pass

    async def test_jwt_token_auth_count_permission_categories(self) -> None:
        """Test case for jwt_token_auth_count_permission_categories

        Count Permission Categories
        """
        pass

    async def test_jwt_token_auth_create_key(self) -> None:
        """Test case for jwt_token_auth_create_key

        Create Key
        """
        pass

    async def test_jwt_token_auth_delete_key(self) -> None:
        """Test case for jwt_token_auth_delete_key

        Delete Key
        """
        pass

    async def test_jwt_token_auth_get_key(self) -> None:
        """Test case for jwt_token_auth_get_key

        Get Key
        """
        pass

    async def test_jwt_token_auth_get_key_specification_url(self) -> None:
        """Test case for jwt_token_auth_get_key_specification_url

        Get Key Specification Url
        """
        pass

    async def test_jwt_token_auth_get_keys(self) -> None:
        """Test case for jwt_token_auth_get_keys

        Get Keys
        """
        pass

    async def test_jwt_token_auth_get_log(self) -> None:
        """Test case for jwt_token_auth_get_log

        Get Log
        """
        pass

    async def test_jwt_token_auth_get_logs(self) -> None:
        """Test case for jwt_token_auth_get_logs

        Get Logs
        """
        pass

    async def test_jwt_token_auth_get_permission_categories(self) -> None:
        """Test case for jwt_token_auth_get_permission_categories

        Get Permission Categories
        """
        pass

    async def test_jwt_token_auth_patch_key(self) -> None:
        """Test case for jwt_token_auth_patch_key

        Patch Key
        """
        pass

    async def test_jwt_token_auth_update_key(self) -> None:
        """Test case for jwt_token_auth_update_key

        Update Key
        """
        pass


if __name__ == '__main__':
    unittest.main()
