# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.api.api_logs_api import ApiLogsApi


class TestApiLogsApi(unittest.IsolatedAsyncioTestCase):
    """ApiLogsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ApiLogsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_jwt_token_auth_count_logs(self) -> None:
        """Test case for jwt_token_auth_count_logs

        Count Logs
        """
        pass

    async def test_jwt_token_auth_get_log(self) -> None:
        """Test case for jwt_token_auth_get_log

        Get Log
        """
        pass

    async def test_jwt_token_auth_get_logs(self) -> None:
        """Test case for jwt_token_auth_get_logs

        Get Logs
        """
        pass


if __name__ == '__main__':
    unittest.main()
